@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <stdlib.h>
 #include <string.h>
@@ -63,7 +63,7 @@ int GModel::readUNV(const std::string &name)
           if(sscanf(buffer, "%d %d %d %d", &num, &dum, &dum, &dum) != 4) break;
           if(!gmshgets(buffer, sizeof(buffer), fp)) break;
           double x, y, z;
-          for(unsigned int i = 0; i < strlen(buffer); i++)
+          for(std::size_t i = 0; i < strlen(buffer); i++)
             if(buffer[i] == 'D') buffer[i] = 'E';
           if(sscanf(buffer, "%lf %lf %lf", &x, &y, &z) != 3) break;
           _vertexMapCache[num] = new MVertex(x, y, z, 0, num);
@@ -280,7 +280,7 @@ static std::string physicalName(GModel *m, int dim, int num)
             num);
     name = tmp;
   }
-  for(unsigned int i = 0; i < name.size(); i++)
+  for(std::size_t i = 0; i < name.size(); i++)
     if(name[i] == ' ') name[i] = '_';
   return name;
 }
@@ -304,17 +304,18 @@ int GModel::writeUNV(const std::string &name, bool saveAll,
   // nodes
   fprintf(fp, "%6d\n", -1);
   fprintf(fp, "%6d\n", 2411);
-  for(unsigned int i = 0; i < entities.size(); i++)
-    for(unsigned int j = 0; j < entities[i]->mesh_vertices.size(); j++)
-      entities[i]->mesh_vertices[j]->writeUNV(fp, scalingFactor);
+  for(std::size_t i = 0; i < entities.size(); i++)
+    for(std::size_t j = 0; j < entities[i]->mesh_vertices.size(); j++)
+      entities[i]->mesh_vertices[j]->writeUNV
+        (fp, CTX::instance()->mesh.unvStrictFormat ? true : false, scalingFactor);
   fprintf(fp, "%6d\n", -1);
 
   // elements
   fprintf(fp, "%6d\n", -1);
   fprintf(fp, "%6d\n", 2412);
-  for(unsigned int i = 0; i < entities.size(); i++) {
+  for(std::size_t i = 0; i < entities.size(); i++) {
     if(saveAll || entities[i]->physicals.size()) {
-      for(unsigned int j = 0; j < entities[i]->getNumMeshElements(); j++) {
+      for(std::size_t j = 0; j < entities[i]->getNumMeshElements(); j++) {
         MElement *e = entities[i]->getMeshElement(j);
         e->writeUNV(fp, e->getNum(), entities[i]->tag(), 0);
       }
@@ -337,8 +338,8 @@ int GModel::writeUNV(const std::string &name, bool saveAll,
 
       std::set<MVertex *> nodes;
       if(saveGroupsOfNodes) {
-        for(unsigned int i = 0; i < entities.size(); i++) {
-          for(unsigned int j = 0; j < entities[i]->getNumMeshElements(); j++) {
+        for(std::size_t i = 0; i < entities.size(); i++) {
+          for(std::size_t j = 0; j < entities[i]->getNumMeshElements(); j++) {
             MElement *e = entities[i]->getMeshElement(j);
             for(std::size_t k = 0; k < e->getNumVertices(); k++)
               nodes.insert(e->getVertex(k));
@@ -347,7 +348,7 @@ int GModel::writeUNV(const std::string &name, bool saveAll,
       }
 
       int nele = 0;
-      for(unsigned int i = 0; i < entities.size(); i++)
+      for(std::size_t i = 0; i < entities.size(); i++)
         nele += entities[i]->getNumMeshElements();
 
       fprintf(fp, "%10d%10d%10d%10d%10d%10d%10d%10d\n", it->first, 0, 0, 0, 0,
@@ -362,7 +363,7 @@ int GModel::writeUNV(const std::string &name, bool saveAll,
             fprintf(fp, "\n");
             row = 0;
           }
-          fprintf(fp, "%10d%10d%10d%10d", 7, (*it2)->getIndex(), 0, 0);
+          fprintf(fp, "%10d%10ld%10d%10d", 7, (*it2)->getIndex(), 0, 0);
           row++;
         }
         fprintf(fp, "\n");
@@ -370,14 +371,14 @@ int GModel::writeUNV(const std::string &name, bool saveAll,
 
       {
         int row = 0;
-        for(unsigned int i = 0; i < entities.size(); i++) {
-          for(unsigned int j = 0; j < entities[i]->getNumMeshElements(); j++) {
+        for(std::size_t i = 0; i < entities.size(); i++) {
+          for(std::size_t j = 0; j < entities[i]->getNumMeshElements(); j++) {
             MElement *e = entities[i]->getMeshElement(j);
             if(row == 2) {
               fprintf(fp, "\n");
               row = 0;
             }
-            fprintf(fp, "%10d%10d%10d%10d", 8, e->getNum(), 0, 0);
+            fprintf(fp, "%10d%10lu%10d%10d", 8, e->getNum(), 0, 0);
             row++;
           }
         }
