@@ -1,10 +1,10 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _GVERTEX_H_
-#define _GVERTEX_H_
+#ifndef GVERTEX_H
+#define GVERTEX_H
 
 #include <list>
 #include <string>
@@ -84,15 +84,15 @@ public:
   virtual void writeGEO(FILE *fp, const std::string &meshSizeParameter = "");
 
   // get number of elements in the mesh
-  size_type getNumMeshElements() const { return points.size(); }
-  unsigned int getNumMeshElementsByType(const int familyType) const;
+  std::size_t getNumMeshElements() const { return points.size(); }
+  std::size_t getNumMeshElementsByType(const int familyType) const;
   void getNumMeshElements(unsigned *const c) const;
 
   // get the element at the given index
-  MElement *getMeshElement(unsigned int index) const;
+  MElement *getMeshElement(std::size_t index) const;
   // get the element at the given index for a given familyType
   MElement *getMeshElementByType(const int familyType,
-                                 const unsigned int index) const;
+                                 const std::size_t index) const;
 
   // return true if this vertex is on a seam of the given face
   bool isOnSeam(const GFace *gf) const;
@@ -106,7 +106,7 @@ public:
   void addElement(int type, MElement *e);
   void removeElement(int type, MElement *e);
 
-  virtual bool reorder(const int elementType, const std::vector<int> &ordering);
+  virtual bool reorder(const int elementType, const std::vector<std::size_t> &ordering);
 };
 
 #endif
