@@ -214,8 +214,24 @@ public:
     return f[face][edge];
   }
   virtual int numCommonNodesInDualGraph(const MElement *const other) const;
-  virtual int getVertexSolin(int numEdge, int numVertex){return 0;}
-  virtual MFace getFaceSolin(int numFace){return getFace(numFace);}
+  virtual int getVertexSolin(int numEdge, int numVertex){
+    static const int eSolin[9][2] =  {{0, 1}, {0, 2}, {0, 3}, {1, 2}, {1, 4},
+                                {2, 5}, {3, 4}, {3, 5}, {4, 5}};
+    return getVertex(eSolin[numEdge][numVertex])->getNum();
+  }
+  virtual MFace getFaceSolin(int numFace){
+    static const int fSolin[5][4] = {
+       {0, 1, 3, 4}, {0, 2, 3, 5}, {1, 2, 4, 5},{0, 1, 2, -1}, {3, 4, 5, -1}};
+      if(numFace > 2){
+        return MFace(_v[fSolin[numFace][0]],_v[fSolin[numFace][1]],
+                     _v[fSolin[numFace][2]]);
+      }
+      else{
+       return MFace(_v[fSolin[numFace][0]], _v[fSolin[numFace][1]],
+                     _v[fSolin[numFace][2]], _v[fSolin[numFace][3]]);
+        }
+
+  }
 };
 
 /*
@@ -604,7 +620,7 @@ public:
       if(_vs.size() == 72) return MSH_PRI_78;
       break;
     }
-    Msg::Error("No tag matches a p%d prism with %d vertices", _order,
+    Msg::Error("No MSH type found for P%d prism with %d nodes", _order,
                6 + _vs.size());
     return 0;
   }
