@@ -3,13 +3,14 @@
 // See the LICENSE.txt file for license information. Please report all
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
-#ifndef _GENERATOR_H_
-#define _GENERATOR_H_
+#ifndef GENERATOR_H
+#define GENERATOR_H
 
 class GModel;
 class GRegion;
 
-void GetStatistics(double stat[50], double quality[4][100] = 0);
+void GetStatistics(double stat[50], double quality[4][100] = 0,
+                   bool visibleOnly = false);
 void AdaptMesh(GModel *m);
 void GenerateMesh(GModel *m, int dimension);
 void OptimizeMesh(GModel *m);
