@@ -4,17 +4,21 @@
 // issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 //
 // Contributed by Ismail Badia.
+// Reference :  "Higher-Order Finite Element  Methods"; Pavel Solin, Karel
+// Segeth ,
+//                 Ivo Dolezel , Chapman and Hall/CRC; Edition : Har/Cdr (2003).
 
 #include "HierarchicalBasisH1Tetra.h"
-
 HierarchicalBasisH1Tetra::HierarchicalBasisH1Tetra(int order)
 {
   _nvertex = 4;
   _nedge = 6;
-  _nface = 4;
+  _nfaceTri = 4;
+  _nfaceQuad = 0;
   _nVertexFunction = 4;
   _nEdgeFunction = 6 * order - 6;
-  _nFaceFunction = 2 * (order - 2) * (order - 1);
+  _nQuadFaceFunction = 0;
+  _nTriFaceFunction = 2 * (order - 2) * (order - 1);
   _nBubbleFunction = (order - 1) * (order - 2) * (order - 3) / 6;
   _pb = order;
   for(int i = 0; i < 4; i++) { _pOrderFace[i] = order; }
@@ -98,7 +102,7 @@ void HierarchicalBasisH1Tetra::generateBasis(double const &u, double const &v,
   edgeProduct[3] = lambda4 * lambda2;
   edgeProduct[4] = lambda4 * lambda1;
   edgeProduct[5] = lambda4 * lambda3;
-  std::vector<double> faceProduct(_nface);
+  std::vector<double> faceProduct(_nfaceTri);
   faceProduct[0] = edgeProduct[0] * lambda1;
   faceProduct[1] = edgeProduct[0] * lambda4;
   faceProduct[2] = edgeProduct[2] * lambda4;
@@ -122,7 +126,7 @@ void HierarchicalBasisH1Tetra::generateBasis(double const &u, double const &v,
   }
   // face shape functions:
   int indexFaceFunction = 0;
-  for(int iFace = 0; iFace < _nface; iFace++) {
+  for(int iFace = 0; iFace < _nfaceTri; iFace++) {
     int indexVectorTarget1 = 0;
     int indexVectorTarget2 = 0;
     switch(iFace) {
@@ -168,9 +172,9 @@ void HierarchicalBasisH1Tetra::generateBasis(double const &u, double const &v,
   }
 }
 
-void HierarchicalBasisH1Tetra::orientateEdge(int const &flagOrientation,
-                                             int const &edgeNumber,
-                                             std::vector<double> &edgeBasis)
+void HierarchicalBasisH1Tetra::orientEdge(int const &flagOrientation,
+                                          int const &edgeNumber,
+                                          std::vector<double> &edgeBasis)
 {
   if(flagOrientation == -1) {
     int constant1 = 0;
@@ -186,7 +190,7 @@ void HierarchicalBasisH1Tetra::orientateEdge(int const &flagOrientation,
     }
   }
 }
-void HierarchicalBasisH1Tetra::orientateEdgeGrad(
+void HierarchicalBasisH1Tetra::orientEdgeGrad(
   int const &flagOrientation, int const &edgeNumber,
   std::vector<std::vector<double> > &gradientEdge)
 {
@@ -209,11 +213,11 @@ void HierarchicalBasisH1Tetra::orientateEdgeGrad(
   }
 }
 
-void HierarchicalBasisH1Tetra::orientateFace(double const &u, double const &v,
-                                             double const &w, int const &flag1,
-                                             int const &flag2, int const &flag3,
-                                             int const &faceNumber,
-                                             std::vector<double> &faceBasis)
+void HierarchicalBasisH1Tetra::orientFace(double const &u, double const &v,
+                                          double const &w, int const &flag1,
+                                          int const &flag2, int const &flag3,
+                                          int const &faceNumber,
+                                          std::vector<double> &faceBasis)
 {
   if(!(flag1 == 0 && flag2 == 1)) {
     // to map onto the reference domain of gmsh:
@@ -223,7 +227,7 @@ void HierarchicalBasisH1Tetra::orientateFace(double const &u, double const &v,
     //*****
     int iterator = 0;
     if(faceNumber > 3) {
-      throw std::string("edgeNumber  must be : 0<=faceNumber<=3");
+      throw std::string("faceNumber  must be : 0<=faceNumber<=3");
     }
     for(int i = 0; i < faceNumber; i++) {
       iterator += int((_pOrderFace[i] - 1) * (_pOrderFace[i] - 2) / 2);
@@ -322,7 +326,7 @@ void HierarchicalBasisH1Tetra::generateGradientBasis(
   dlambda1[1] = 0.5;
   dlambda3[0] = 0.5;
   dlambda4[2] = 0.5;
-  std::vector<double> dprod(3);
+  std::vector<double> dprod(3); // d(lambda1*lambda2*lambda3*lambda4)
   dprod[0] = jacob * (lambda1 * dlambda2[0] * lambda3 * lambda4 +
                       lambda1 * lambda2 * dlambda3[0] * lambda4);
   dprod[1] = jacob * (dlambda1[1] * lambda2 * lambda3 * lambda4 +
@@ -423,14 +427,13 @@ void HierarchicalBasisH1Tetra::generateGradientBasis(
     dEdgeProduct[5][i] =
       jacob * (dlambda4[i] * lambda3 + lambda4 * dlambda3[i]);
   }
-  std::vector<double> faceProduct(_nface);
+  std::vector<double> faceProduct(_nfaceTri);
   faceProduct[0] = edgeProduct[0] * lambda1;
   faceProduct[1] = edgeProduct[0] * lambda4;
   faceProduct[2] = edgeProduct[2] * lambda4;
   faceProduct[3] = edgeProduct[1] * lambda4;
-  std::vector<std::vector<double> > dfaceProduct(_nface,
+  std::vector<std::vector<double> > dfaceProduct(_nfaceTri,
                                                  std::vector<double>(3));
-
   for(int i = 0; i < 3; i++) {
     dfaceProduct[0][i] =
       jacob * (edgeProduct[0] * dlambda1[i]) + dEdgeProduct[0][i] * lambda1;
@@ -447,16 +450,14 @@ void HierarchicalBasisH1Tetra::generateGradientBasis(
     for(int indexEdgeFunc = 0; indexEdgeFunc < _pOrderEdge[iEdge] - 1;
         indexEdgeFunc++) {
       int impact1 = 1;
-      int impact2 = 1;
       if(iEdge == 2) {
         impact1 = 1;
-        impact2 = -1;
         if(indexEdgeFunc % 2 != 0) { impact1 = -1; }
       }
       for(int i = 0; i < 3; i++) {
         gradientEdge[indexEdgeBasis][i] =
           impact1 * (dEdgeProduct[iEdge][i] * phi[iEdge][indexEdgeFunc] +
-                     impact2 * edgeProduct[iEdge] * dphi[iEdge][indexEdgeFunc] *
+                     edgeProduct[iEdge] * dphi[iEdge][indexEdgeFunc] *
                        dsubstraction[iEdge][i]);
       }
       indexEdgeBasis++;
@@ -464,7 +465,7 @@ void HierarchicalBasisH1Tetra::generateGradientBasis(
   }
   // face shape functions:
   int indexFaceFunction = 0;
-  for(int iFace = 0; iFace < _nface; iFace++) {
+  for(int iFace = 0; iFace < _nfaceTri; iFace++) {
     int indexVectorTarget1 = 0;
     int indexVectorTarget2 = 0;
     switch(iFace) {
@@ -495,7 +496,7 @@ void HierarchicalBasisH1Tetra::generateGradientBasis(
                         phi[indexVectorTarget2][n2] +
                       faceProduct[iFace] * dphi[indexVectorTarget1][n1] *
                         dsubstraction[indexVectorTarget1][i] *
-                        phi[indexVectorTarget2][n2] -
+                        phi[indexVectorTarget2][n2] +
                       faceProduct[iFace] * phi[indexVectorTarget1][n1] *
                         dsubstraction[indexVectorTarget2][i] *
                         dphi[indexVectorTarget2][n2]);
@@ -522,7 +523,7 @@ void HierarchicalBasisH1Tetra::generateGradientBasis(
   }
 }
 
-void HierarchicalBasisH1Tetra::orientateFaceGrad(
+void HierarchicalBasisH1Tetra::orientFaceGrad(
   double const &u, double const &v, double const &w, int const &flag1,
   int const &flag2, int const &flag3, int const &faceNumber,
   std::vector<std::vector<double> > &gradientFace)
@@ -535,7 +536,7 @@ void HierarchicalBasisH1Tetra::orientateFaceGrad(
     //*****
     int iterator = 0;
     if(faceNumber > 3) {
-      throw std::string("edgeNumber  must be : 0<=faceNumber<=3");
+      throw std::string("faceNumber  must be : 0<=faceNumber<=3");
     }
     for(int i = 0; i < faceNumber; i++) {
       iterator += int((_pOrderFace[i] - 1) * (_pOrderFace[i] - 2) / 2);
@@ -555,7 +556,7 @@ void HierarchicalBasisH1Tetra::orientateFaceGrad(
       dlambda[2][1] = 1; //* jacobian
       double pl3l1 = lambda[1] * lambda[2];
       dProduct[0] = lambda[2] * lambda[0] - pl3l1;
-      dProduct[1] = lambda[2] * lambda[1] - pl3l1;
+      dProduct[1] = lambda[0] * lambda[1] - pl3l1;
       dProduct[2] = -pl3l1; //*jacobian
       break;
     }
