@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2019 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include "pointsGenerators.h"
 #include "GmshDefines.h"
@@ -980,8 +980,9 @@ fullMatrix<double> gmshGenerateMonomialsPyramidGeneral(bool pyr, int nij,
                                                        bool forSerendipPoints)
 {
   if(nij < 0 || nk < 0) {
-    Msg::Fatal("Wrong arguments for pyramid's monomials generation ! (%d & %d)",
+    Msg::Error("Wrong arguments for pyramid's monomials generation ! (%d & %d)",
                nij, nk);
+    nij = nk = 1;
   }
   if(!pyr && nk > 0 && nij == 0) {
     Msg::Error("Wrong argument association for pyramid's monomials generation! "
