@@ -31,12 +31,12 @@ public:
 
   virtual void f(double u, double v, double w, double *sf) const;
   virtual void f(const fullMatrix<double> &coord, fullMatrix<double> &sf) const;
-  virtual void df(const fullMatrix<double> &coord,
-                  fullMatrix<double> &dfm) const;
+  virtual void f(double u, double v, double w, int i, double *sf) const;
+  virtual void df(const fullMatrix<double> &coord, fullMatrix<double> &dfm) const;
   virtual void df(double u, double v, double w, double grads[][3]) const;
+  virtual void df(double u, double v, double w, int i, double grad[3]) const;
   virtual void ddf(double u, double v, double w, double hess[][3][3]) const;
-  virtual void dddf(double u, double v, double w,
-                    double third[][3][3][3]) const;
+  virtual void dddf(double u, double v, double w, double third[][3][3][3]) const;
 
   void evaluateMonomials(double u, double v, double w, double p[]) const;
 };
