@@ -118,166 +118,168 @@ extern int gmsh_yydebug;
     tCurrentDirectory = 324,
     tSyncModel = 325,
     tNewModel = 326,
-    tOnelabAction = 327,
-    tOnelabRun = 328,
-    tCodeName = 329,
-    tCpu = 330,
-    tMemory = 331,
-    tTotalMemory = 332,
-    tCreateTopology = 333,
-    tCreateGeometry = 334,
-    tRenumberMeshNodes = 335,
-    tRenumberMeshElements = 336,
-    tDistanceFunction = 337,
-    tDefineConstant = 338,
-    tUndefineConstant = 339,
-    tDefineNumber = 340,
-    tDefineStruct = 341,
-    tNameStruct = 342,
-    tDimNameSpace = 343,
-    tAppend = 344,
-    tDefineString = 345,
-    tSetNumber = 346,
-    tSetTag = 347,
-    tSetString = 348,
-    tPoint = 349,
-    tCircle = 350,
-    tEllipse = 351,
-    tCurve = 352,
-    tSphere = 353,
-    tPolarSphere = 354,
-    tSurface = 355,
-    tSpline = 356,
-    tVolume = 357,
-    tBox = 358,
-    tCylinder = 359,
-    tCone = 360,
-    tTorus = 361,
-    tEllipsoid = 362,
-    tQuadric = 363,
-    tShapeFromFile = 364,
-    tRectangle = 365,
-    tDisk = 366,
-    tWire = 367,
-    tGeoEntity = 368,
-    tCharacteristic = 369,
-    tLength = 370,
-    tParametric = 371,
-    tElliptic = 372,
-    tRefineMesh = 373,
-    tAdaptMesh = 374,
-    tRelocateMesh = 375,
-    tReorientMesh = 376,
-    tSetFactory = 377,
-    tThruSections = 378,
-    tWedge = 379,
-    tFillet = 380,
-    tChamfer = 381,
-    tPlane = 382,
-    tRuled = 383,
-    tTransfinite = 384,
-    tPhysical = 385,
-    tCompound = 386,
-    tPeriodic = 387,
-    tParent = 388,
-    tUsing = 389,
-    tPlugin = 390,
-    tDegenerated = 391,
-    tRecursive = 392,
-    tRotate = 393,
-    tTranslate = 394,
-    tSymmetry = 395,
-    tDilate = 396,
-    tExtrude = 397,
-    tLevelset = 398,
-    tAffine = 399,
-    tBooleanUnion = 400,
-    tBooleanIntersection = 401,
-    tBooleanDifference = 402,
-    tBooleanSection = 403,
-    tBooleanFragments = 404,
-    tThickSolid = 405,
-    tRecombine = 406,
-    tSmoother = 407,
-    tSplit = 408,
-    tDelete = 409,
-    tCoherence = 410,
-    tIntersect = 411,
-    tMeshAlgorithm = 412,
-    tReverseMesh = 413,
-    tLayers = 414,
-    tScaleLast = 415,
-    tHole = 416,
-    tAlias = 417,
-    tAliasWithOptions = 418,
-    tCopyOptions = 419,
-    tQuadTriAddVerts = 420,
-    tQuadTriNoNewVerts = 421,
-    tRecombLaterals = 422,
-    tTransfQuadTri = 423,
-    tText2D = 424,
-    tText3D = 425,
-    tInterpolationScheme = 426,
-    tTime = 427,
-    tCombine = 428,
-    tBSpline = 429,
-    tBezier = 430,
-    tNurbs = 431,
-    tNurbsOrder = 432,
-    tNurbsKnots = 433,
-    tColor = 434,
-    tColorTable = 435,
-    tFor = 436,
-    tIn = 437,
-    tEndFor = 438,
-    tIf = 439,
-    tElseIf = 440,
-    tElse = 441,
-    tEndIf = 442,
-    tExit = 443,
-    tAbort = 444,
-    tField = 445,
-    tReturn = 446,
-    tCall = 447,
-    tSlide = 448,
-    tMacro = 449,
-    tShow = 450,
-    tHide = 451,
-    tGetValue = 452,
-    tGetStringValue = 453,
-    tGetEnv = 454,
-    tGetString = 455,
-    tGetNumber = 456,
-    tUnique = 457,
-    tHomology = 458,
-    tCohomology = 459,
-    tBetti = 460,
-    tExists = 461,
-    tFileExists = 462,
-    tGetForced = 463,
-    tGetForcedStr = 464,
-    tGMSH_MAJOR_VERSION = 465,
-    tGMSH_MINOR_VERSION = 466,
-    tGMSH_PATCH_VERSION = 467,
-    tGmshExecutableName = 468,
-    tSetPartition = 469,
-    tNameToString = 470,
-    tStringToName = 471,
-    tAFFECTPLUS = 472,
-    tAFFECTMINUS = 473,
-    tAFFECTTIMES = 474,
-    tAFFECTDIVIDE = 475,
-    tOR = 476,
-    tAND = 477,
-    tEQUAL = 478,
-    tNOTEQUAL = 479,
-    tLESSOREQUAL = 480,
-    tGREATEROREQUAL = 481,
-    tLESSLESS = 482,
-    tGREATERGREATER = 483,
-    tPLUSPLUS = 484,
-    tMINUSMINUS = 485,
-    UNARYPREC = 486
+    tMass = 327,
+    tCenterOfMass = 328,
+    tOnelabAction = 329,
+    tOnelabRun = 330,
+    tCodeName = 331,
+    tCpu = 332,
+    tMemory = 333,
+    tTotalMemory = 334,
+    tCreateTopology = 335,
+    tCreateGeometry = 336,
+    tRenumberMeshNodes = 337,
+    tRenumberMeshElements = 338,
+    tDistanceFunction = 339,
+    tDefineConstant = 340,
+    tUndefineConstant = 341,
+    tDefineNumber = 342,
+    tDefineStruct = 343,
+    tNameStruct = 344,
+    tDimNameSpace = 345,
+    tAppend = 346,
+    tDefineString = 347,
+    tSetNumber = 348,
+    tSetTag = 349,
+    tSetString = 350,
+    tPoint = 351,
+    tCircle = 352,
+    tEllipse = 353,
+    tCurve = 354,
+    tSphere = 355,
+    tPolarSphere = 356,
+    tSurface = 357,
+    tSpline = 358,
+    tVolume = 359,
+    tBox = 360,
+    tCylinder = 361,
+    tCone = 362,
+    tTorus = 363,
+    tEllipsoid = 364,
+    tQuadric = 365,
+    tShapeFromFile = 366,
+    tRectangle = 367,
+    tDisk = 368,
+    tWire = 369,
+    tGeoEntity = 370,
+    tCharacteristic = 371,
+    tLength = 372,
+    tParametric = 373,
+    tElliptic = 374,
+    tRefineMesh = 375,
+    tAdaptMesh = 376,
+    tRelocateMesh = 377,
+    tReorientMesh = 378,
+    tSetFactory = 379,
+    tThruSections = 380,
+    tWedge = 381,
+    tFillet = 382,
+    tChamfer = 383,
+    tPlane = 384,
+    tRuled = 385,
+    tTransfinite = 386,
+    tPhysical = 387,
+    tCompound = 388,
+    tPeriodic = 389,
+    tParent = 390,
+    tUsing = 391,
+    tPlugin = 392,
+    tDegenerated = 393,
+    tRecursive = 394,
+    tRotate = 395,
+    tTranslate = 396,
+    tSymmetry = 397,
+    tDilate = 398,
+    tExtrude = 399,
+    tLevelset = 400,
+    tAffine = 401,
+    tBooleanUnion = 402,
+    tBooleanIntersection = 403,
+    tBooleanDifference = 404,
+    tBooleanSection = 405,
+    tBooleanFragments = 406,
+    tThickSolid = 407,
+    tRecombine = 408,
+    tSmoother = 409,
+    tSplit = 410,
+    tDelete = 411,
+    tCoherence = 412,
+    tIntersect = 413,
+    tMeshAlgorithm = 414,
+    tReverseMesh = 415,
+    tLayers = 416,
+    tScaleLast = 417,
+    tHole = 418,
+    tAlias = 419,
+    tAliasWithOptions = 420,
+    tCopyOptions = 421,
+    tQuadTriAddVerts = 422,
+    tQuadTriNoNewVerts = 423,
+    tRecombLaterals = 424,
+    tTransfQuadTri = 425,
+    tText2D = 426,
+    tText3D = 427,
+    tInterpolationScheme = 428,
+    tTime = 429,
+    tCombine = 430,
+    tBSpline = 431,
+    tBezier = 432,
+    tNurbs = 433,
+    tNurbsOrder = 434,
+    tNurbsKnots = 435,
+    tColor = 436,
+    tColorTable = 437,
+    tFor = 438,
+    tIn = 439,
+    tEndFor = 440,
+    tIf = 441,
+    tElseIf = 442,
+    tElse = 443,
+    tEndIf = 444,
+    tExit = 445,
+    tAbort = 446,
+    tField = 447,
+    tReturn = 448,
+    tCall = 449,
+    tSlide = 450,
+    tMacro = 451,
+    tShow = 452,
+    tHide = 453,
+    tGetValue = 454,
+    tGetStringValue = 455,
+    tGetEnv = 456,
+    tGetString = 457,
+    tGetNumber = 458,
+    tUnique = 459,
+    tHomology = 460,
+    tCohomology = 461,
+    tBetti = 462,
+    tExists = 463,
+    tFileExists = 464,
+    tGetForced = 465,
+    tGetForcedStr = 466,
+    tGMSH_MAJOR_VERSION = 467,
+    tGMSH_MINOR_VERSION = 468,
+    tGMSH_PATCH_VERSION = 469,
+    tGmshExecutableName = 470,
+    tSetPartition = 471,
+    tNameToString = 472,
+    tStringToName = 473,
+    tAFFECTPLUS = 474,
+    tAFFECTMINUS = 475,
+    tAFFECTTIMES = 476,
+    tAFFECTDIVIDE = 477,
+    tOR = 478,
+    tAND = 479,
+    tEQUAL = 480,
+    tNOTEQUAL = 481,
+    tLESSOREQUAL = 482,
+    tGREATEROREQUAL = 483,
+    tLESSLESS = 484,
+    tGREATERGREATER = 485,
+    tPLUSPLUS = 486,
+    tMINUSMINUS = 487,
+    UNARYPREC = 488
   };
 #endif
 
@@ -297,7 +299,7 @@ union YYSTYPE
   List_T *l;
   struct TwoChar c2;
 
-#line 301 "Gmsh.tab.hpp" /* yacc.c:1921  */
+#line 303 "Gmsh.tab.hpp" /* yacc.c:1921  */
 };
 
 typedef union YYSTYPE YYSTYPE;
