@@ -140,7 +140,7 @@ def ivectordouble(name, value=None, python_value=None, julia_value=None):
     a.python_pre = api_name + ", " + api_name_n + " = _ivectordouble(" + name + ")"
     a.python_arg = api_name + ", " + api_name_n
     a.julia_ctype = "Ptr{Cdouble}, Csize_t"
-    a.julia_arg = name + ", length(" + name + ")"
+    a.julia_arg = "convert(Vector{Cdouble}, " + name + "), length(" + name + ")"
     return a
 
 def ivectorstring(name, value=None, python_value=None, julia_value=None):
@@ -1122,6 +1122,8 @@ julia_header = """# {0}
 # types. See `demos/api' for examples.
 """
 
+def capi(s): return s[:1].upper() + s[1:]
+
 class API:
 
     def __init__(self, version_major, version_minor, namespace="gmsh", code="Gmsh",
@@ -1143,7 +1145,8 @@ class API:
 
     def write_cpp(self):
         def write_module(module, indent):
-            f.write(indent + "namespace " + module.name + " { // " + module.doc + "\n\n")
+            f.write(indent + "namespace " + module.name + " { // " +
+                    capi(module.doc) + "\n\n")
             indent += "  "
             for rtype, name, args, doc, special in module.fs:
                 f.write(indent + "// " + ("\n" + indent + "// ").join(
@@ -1171,7 +1174,8 @@ class API:
                 c_namespace += module.name[0].upper() + module.name[1:]
             else:
                 c_namespace = module.name
-            fcwrap.write(indent + "namespace " + module.name + " { // " + module.doc + "\n\n")
+            fcwrap.write(indent + "namespace " + module.name + " { // " +
+                         capi(module.doc) + "\n\n")
             indent += "  "
             for rtype, name, args, doc, special in module.fs:
                 # *c.h
@@ -1315,7 +1319,8 @@ class API:
                 f.write("\n\n" + indent + "class " + module.name + ":\n")
                 indentm = indent + "    "
                 f.write(indentm + '"""\n')
-                f.write(indentm + ("\n" + indentm).join(textwrap.wrap(module.doc, 75)) + "\n")
+                f.write(indentm + ("\n" + indentm).join
+                        (textwrap.wrap(capi(module.doc), 75)) + "\n")
                 f.write(indentm + '"""\n')
                 write_module(f, module, modulepath, indentm)
         with open(ns + ".py", "w") as f:
@@ -1373,7 +1378,7 @@ class API:
         def write_module(f, m, c_mpath, jl_mpath, level):
             f.write('\n"""\n    ')
             f.write("module " + jl_mpath + m.name + "\n\n")
-            f.write("\n".join(textwrap.wrap(m.doc, 80)) + "\n")
+            f.write("\n".join(textwrap.wrap(capi(m.doc), 80)) + "\n")
             f.write('"""\n')
             f.write("module " + m.name + "\n\n")
             if level == 1:
@@ -1409,9 +1414,9 @@ class API:
                 write_module(f, module, "", "", 1)
 
     def write_texi(self):
-        def write_module(module, parent):
-            full = parent + "/" + module.name
-            f.write("@heading Module @code{" + full + "}\n");
+        def write_module(module, path, node, node_next, node_prev):
+            f.write("@node " + node + ", " + node_next + ", " + node_prev + ", Gmsh API\n");
+            f.write("@section Namespace @code{" + path + "}: " + module.doc + "\n\n");
             f.write("@ftable @code\n");
             for rtype, name, args, doc, special in module.fs:
                 f.write("@item " + name + "\n");
@@ -1430,9 +1435,24 @@ class API:
                         (rtype.rtexi_type if rtype else "-") + "\n")
                 f.write("@end table\n\n");
             f.write("@end ftable\n\n");
-            for m in module.submodules:
-                write_module(m, full)
         with open("api.texi", "w") as f:
             f.write("@c This file was generated by api/gen.py: do not edit manually!\n\n")
+            def flatten_module(flat, module, path):
+                p = path + ("/" if len(path) else "") + module.name
+                flat.append((module, p))
+                for m in module.submodules:
+                    flatten_module(flat, m, p)
+            def node_name(n):
+                return "Namespace " + n[1]
+            flat = []
             for m in self.modules:
-                write_module(m, "")
+                flatten_module(flat, m, "")
+            N = len(flat)
+            f.write("@menu\n")
+            for i in range(N):
+                f.write("* " + node_name(flat[i]) + "::\n")
+            f.write("@end menu\n\n")
+            for i in range(N):
+                write_module(flat[i][0], flat[i][1], node_name(flat[i]),
+                             "" if i == N - 1 else node_name(flat[i+1]),
+                             "" if i == 0 else node_name(flat[i-1]))
